@@ -249,6 +249,7 @@ void Dynamic::map_message(pTHX_ const Descriptor *descriptor, const string &perl
     copy_and_bind(aTHX_ "decode", perl_package, mapper);
     copy_and_bind(aTHX_ "encode", perl_package, mapper);
     copy_and_bind(aTHX_ "new", perl_package, mapper);
+    copy_and_bind(aTHX_ "message_descriptor", perl_package, mapper);
 
     if (options.generic_extension_methods) {
         copy_and_bind(aTHX_ "has_extension_field", "has_extension", perl_package, mapper);
@@ -340,6 +341,7 @@ void Dynamic::map_enum(pTHX_ const EnumDescriptor *descriptor, const string &per
 void Dynamic::resolve_references() {
     for (std::vector<Mapper *>::iterator it = pending.begin(), en = pending.end(); it != en; ++it)
         (*it)->resolve_mappers();
+    pending.clear();
 }
 
 const Mapper *Dynamic::find_mapper(const MessageDef *message_def) const {
