@@ -603,6 +603,14 @@ const Mapper::Field *Mapper::get_field(int index) const {
     return &fields[index];
 }
 
+SV *Mapper::message_descriptor() const {
+    SV *ref = newSV(0);
+
+    sv_setref_iv(ref, "Google::ProtocolBuffers::Dynamic::MessageDef", (IV) message_def);
+
+    return ref;
+}
+
 void Mapper::resolve_mappers() {
     for (vector<Field>::iterator it = fields.begin(), en = fields.end(); it != en; ++it) {
         const FieldDef *field = it->field_def;
@@ -621,6 +629,8 @@ void Mapper::resolve_mappers() {
 }
 
 SV *Mapper::encode(SV *ref) {
+    if (encoder == NULL)
+        croak("It looks like resolve_references() was not called (and please use map() anyway)");
     status.Clear();
     output_buffer.clear();
     SV *result = NULL;
@@ -632,6 +642,8 @@ SV *Mapper::encode(SV *ref) {
 }
 
 SV *Mapper::decode(const char *buffer, STRLEN bufsize) {
+    if (decoder == NULL)
+        croak("It looks like resolve_references() was not called (and please use map() anyway)");
     status.Clear();
     decoder->Reset();
     decoder_callbacks.prepare(newHV());
@@ -1336,18 +1348,18 @@ void MapperField::add_item(HV *self, SV *value) {
 }
 
 int MapperField::list_size(HV *self) {
-    AV *target = get_read_array(self);
+    AV *array = get_read_array(self);
 
-    if (!target)
+    if (!array)
         return 0;
 
-    return av_top_index(target) + 1;
+    return av_top_index(array) + 1;
 }
 
 void MapperField::get_list(HV *self, SV *target) {
     AV *array = get_read_array(self);
 
-    if (!target) {
+    if (!array) {
         sv_setsv(target, &PL_sv_undef);
     } else {
         SvUPGRADE(target, SVt_RV);
